@@ -1,51 +1,45 @@
 // SPDX-License-Identifier: Apache-2.0
 
-#[cfg(feature = "backend-kvm")]
+#[cfg(enarx_with_shim)]
 pub mod kvm;
 
-#[cfg(feature = "backend-sev")]
+#[cfg(enarx_with_shim)]
 pub mod sev;
 
-#[cfg(feature = "backend-sgx")]
+#[cfg(enarx_with_shim)]
 pub mod sgx;
 
+pub mod nil;
+
+#[cfg(enarx_with_shim)]
 mod binary;
+
+#[cfg(enarx_with_shim)]
 mod probe;
 
-use binary::Binary;
+#[cfg(enarx_with_shim)]
+use binary::{Binary, Loader, Mapper};
 
-use std::convert::TryFrom;
 use std::sync::Arc;
 
-use anyhow::{Error, Result};
+use anyhow::Result;
 use libc::c_int;
-use mmarinus::{perms, Map};
 use once_cell::sync::Lazy;
 use serde::ser::{Serialize, SerializeStruct, Serializer};
 
-trait Config: Sized {
+#[cfg(not(enarx_with_shim))]
+#[allow(dead_code)]
+pub struct Binary<'a> {
+    phantom: std::marker::PhantomData<&'a ()>,
+}
+
+pub(crate) trait Config: Sized {
     type Flags;
 
     fn flags(flags: u32) -> Self::Flags;
     fn new(shim: &Binary<'_>, exec: &Binary<'_>) -> Result<Self>;
 }
 
-trait Mapper: Sized + TryFrom<Self::Config, Error = Error> {
-    type Config: Config;
-    type Output: TryFrom<Self, Error = Error>;
-
-    fn map(
-        &mut self,
-        pages: Map<perms::ReadWrite>,
-        to: usize,
-        with: <Self::Config as Config>::Flags,
-    ) -> Result<()>;
-}
-
-trait Loader: Mapper {
-    fn load(shim: impl AsRef<[u8]>, exec: impl AsRef<[u8]>) -> Result<Self::Output>;
-}
-
 pub trait Backend: Sync + Send {
     /// The name of the backend
     fn name(&self) -> &'static str;
@@ -110,12 +104,13 @@ pub enum Command {
 
 pub static BACKENDS: Lazy<Vec<Box<dyn Backend>>> = Lazy::new(|| {
     vec![
-        #[cfg(feature = "backend-sgx")]
+        #[cfg(enarx_with_shim)]
         Box::new(sgx::Backend),
-        #[cfg(feature = "backend-sev")]
+        #[cfg(enarx_with_shim)]
         Box::new(sev::Backend),
-        #[cfg(feature = "backend-kvm")]
+        #[cfg(enarx_with_shim)]
         Box::new(kvm::Backend),
+        Box::new(nil::Backend),
     ]
 });
 
