@@ -1,12 +1,14 @@
 // SPDX-License-Identifier: Apache-2.0
 
 use crate::backend::probe::x86_64::{CpuId, Vendor};
+use crate::backend::sgx::AESM_SOCKET;
 use crate::backend::Datum;
 
 use sgx::parameters::{Features, MiscSelect, Xfrm};
 
 use std::arch::x86_64::__cpuid_count;
 use std::fs::File;
+use std::path::Path;
 
 fn humanize(mut size: f64) -> (f64, &'static str) {
     let mut iter = 0;
@@ -154,16 +156,19 @@ pub fn epc_size(max: u32) -> Datum {
 }
 
 pub fn dev_sgx_enclave() -> Datum {
-    let mut pass = false;
-
-    if File::open("/dev/sgx_enclave").is_ok() {
-        pass = true;
-    }
-
     Datum {
         name: "Driver".into(),
-        pass,
+        pass: File::open("/dev/sgx_enclave").is_ok(),
         info: Some("/dev/sgx_enclave".into()),
         mesg: None,
     }
 }
+
+pub fn aesm_socket() -> Datum {
+    Datum {
+        name: "AESM Daemon Socket".into(),
+        pass: cfg!(feature = "disable-sgx-attestation") || Path::new(AESM_SOCKET).exists(),
+        info: Some(AESM_SOCKET.into()),
+        mesg: None,
+    }
+}
