@@ -15,6 +15,7 @@ use anyhow::Result;
 use mmarinus::{perms, Map};
 
 use std::arch::x86_64::__cpuid_count;
+use std::fs::File;
 use std::sync::{Arc, RwLock};
 
 pub const AESM_SOCKET: &str = "/var/run/aesmd/aesm.socket";
@@ -23,8 +24,9 @@ struct Tcs;
 
 struct Keep {
     sallyport_block_size: u64,
-    _mem: Map<perms::Unknown>,
+    mem: Map<perms::Unknown>,
     tcs: RwLock<Vec<*const Tcs>>,
+    enclave: File,
 }
 
 pub struct Backend;
@@ -66,3 +68,22 @@ impl crate::backend::Backend for Backend {
         hasher::Hasher::load(shim, exec)
     }
 }
+
+#[cfg(test)]
+mod tests {
+    #[test]
+    #[cfg_attr(debug_assertions, ignore)]
+    fn shim_sgx_binary_size() {
+        use crate::backend::Backend;
+
+        let max_shim_size = 500_000;
+        let shim = super::Backend.shim();
+        if shim.len() > max_shim_size {
+            panic!(
+                "shim size should be less than {} bytes, but is {} bytes",
+                max_shim_size,
+                shim.len()
+            );
+        }
+    }
+}
