@@ -1,9 +1,11 @@
 // SPDX-License-Identifier: Apache-2.0
 
-use crate::cli::{BackendOptions, StructOpt};
+use crate::cli::BackendOptions;
 
 use std::path::PathBuf;
 
+use clap::Args;
+
 /// Execute a (static, PIE) binary inside an Enarx Keep.
 ///
 /// The binary must be a statically linked position-independent executable,
@@ -14,17 +16,17 @@ use std::path::PathBuf;
 /// This subcommand is hidden from the main help because it's unlikely to be
 /// useful because of the restrictions above. It's mainly used for
 /// development and integration tests.
-#[derive(StructOpt, Debug)]
+#[derive(Args, Debug)]
 pub struct Options {
-    #[structopt(flatten)]
+    #[clap(flatten)]
     pub backend: BackendOptions,
 
     /// Binary to load and run inside the keep
-    #[structopt(value_name = "BINARY")]
+    #[clap(value_name = "BINARY")]
     pub binpath: PathBuf,
 
     /// gdb options
     #[cfg(feature = "gdb")]
-    #[structopt(long, default_value = "localhost:23456")]
+    #[clap(long, default_value = "localhost:23456")]
     pub gdblisten: String,
 }
