@@ -1,12 +1,13 @@
 // SPDX-License-Identifier: Apache-2.0
 
+pub mod deploy;
 mod exec;
 mod info;
 mod log;
-mod run;
-#[cfg(feature = "backend-sgx")]
+pub mod run;
+#[cfg(enarx_with_shim)]
 pub mod sgx;
-#[cfg(feature = "backend-sev")]
+#[cfg(enarx_with_shim)]
 pub mod snp;
 
 use anyhow::{anyhow, Result};
@@ -22,10 +23,11 @@ pub enum Command {
     #[clap(hide = true)]
     Exec(exec::Options),
     Run(run::Options),
-    #[cfg(feature = "backend-sev")]
+    Deploy(deploy::Options),
+    #[cfg(enarx_with_shim)]
     #[clap(subcommand)]
     Snp(snp::Command),
-    #[cfg(feature = "backend-sgx")]
+    #[cfg(enarx_with_shim)]
     #[clap(subcommand)]
     Sgx(sgx::Command),
 }
@@ -63,26 +65,3 @@ impl BackendOptions {
         .map(|b| &**b)
     }
 }
-
-//
-// Options & shared setup code for workldr
-//
-use crate::workldr::{Workldr, WORKLDRS};
-
-#[derive(Args, Debug)]
-pub struct WorkldrOptions {
-    #[clap(long, env = "ENARX_WASMCFGFILE")]
-    pub wasmcfgfile: Option<String>,
-    // FUTURE: Path to an external workldr binary
-}
-
-impl WorkldrOptions {
-    pub fn pick(&self) -> Result<&dyn Workldr> {
-        WORKLDRS
-            .deref()
-            .iter()
-            .find(|_| true)
-            .ok_or_else(|| anyhow!("No supported workldr found"))
-            .map(|b| &**b)
-    }
-}
