@@ -1,8 +1,9 @@
 // SPDX-License-Identifier: Apache-2.0
 
-use super::{BackendOptions, WorkldrOptions};
+use super::BackendOptions;
 
-use std::{fmt::Debug, path::PathBuf};
+use std::fmt::Debug;
+use std::path::PathBuf;
 
 use clap::Args;
 
@@ -12,8 +13,8 @@ pub struct Options {
     #[clap(flatten)]
     pub backend: BackendOptions,
 
-    #[clap(flatten)]
-    pub workldr: WorkldrOptions,
+    #[clap(long, env = "ENARX_WASMCFGFILE")]
+    pub wasmcfgfile: Option<PathBuf>,
 
     /// Path of the WebAssembly module to run
     #[clap(value_name = "MODULE", parse(from_os_str))]
